@@ -56,10 +56,11 @@ def print(*args, error=False, warn=False, highlight=False, color="", input=False
     if input: # in case we want to stop here and let the user press key to proceed
         post_str = " Press Enter to proceed..."
     # print
-    builtin_print(color_str+message, end="")
-    builtin_print(*args, **kwargs, end="")
-    builtin_print(post_str, end="")
-    builtin_print(color_str, end=f"{Style.RESET_ALL}\n", flush=True)
+    builtin_print(color_str+message, end="") # print in colour and message, if requested
+    builtin_print(*args, **kwargs, end="") # print the actual stuff
+    builtin_print(post_str, end="") # print a post string, if requested
+    if color_str != "": builtin_print(f"{Style.RESET_ALL}", end="") # reset, in case we used ANSI for colouring text
+    builtin_print("", flush=True) # print final line ending, and flush output
     if input: builtin_input() # this will ask for user press key...
     # error handling (exit or stop the code)
     if error:
